[Xfce4-commits] [apps/xfce4-terminal] 01/01: Move window to foreground when using --tab option

noreply at xfce.org noreply at xfce.org
Thu Jul 7 20:25:24 CEST 2016


This is an automated email from the git hooks/post-receive script.

f2404 pushed a commit to branch master
in repository apps/xfce4-terminal.

commit 1a8ae91fcbf301f0810d4c2d0e48b3d84e0549ef
Author: Igor <f2404 at yandex.ru>
Date:   Thu Jul 7 21:24:28 2016 +0300

    Move window to foreground when using --tab option
    
    Fixes #11010
---
 terminal/terminal-app.c | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/terminal/terminal-app.c b/terminal/terminal-app.c
index 9f82146..82242cf 100644
--- a/terminal/terminal-app.c
+++ b/terminal/terminal-app.c
@@ -757,9 +757,12 @@ terminal_app_open_window (TerminalApp        *app,
 
   if (!attr->drop_down)
     {
       /* don't apply other attributes to the window when reusing */
       if (reuse_window)
-        return;
+        {
+          gtk_window_present (GTK_WINDOW (window));
+          return;
+        }
 
       /* set the window geometry, this can only be set after one of the tabs
        * has been added, because vte is the geometry widget, so atleast one
@@ -757,9 +757,12 @@ terminal_app_open_window (TerminalApp        *app,
   if (!attr->drop_down)
     {
-      /* don't apply other attributes to the window when reusing */
+      /* don't apply other attributes to the window when reusing, just present it to user */
       if (reuse_window)

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list